@@ -10,8 +10,8 @@ from PySide6.QtWidgets import (QApplication, QToolBar, QWidget, QPushButton, QTo
                                QCalendarWidget, QGroupBox, QFileDialog, QDateEdit, QMenu)
 from PySide6.QtWidgets import (QMessageBox)
 
-from yut.win32 import set_process_user_model_id
 from yut import get_attr, is_execute_able, call_exp
+from yut.win32 import set_process_user_model_id
 
 
 class Theme(Enum):
@@ -152,10 +152,19 @@ def create_button(text='', trigger=None, icon=None, icon_file=None, flat=None, t
     return btn
 
 
-def create_tool_button(text='', trigger=None, icon=None, icon_file=None, tip_text=None, parent=None,
+def create_tool_button(text='',
+                       trigger=None,
+                       icon=None,
+                       icon_file=None,
+                       tip_text=None,
+                       parent=None,
                        icon_size: QSize | int = None,
-                       flat=False, object_name=None) -> QToolButton:
+                       button_style=Qt.ToolButtonStyle.ToolButtonIconOnly,
+                       flat=False,
+                       object_name=None,
+                       ) -> QToolButton:
     btn = QToolButton(parent=parent)
+    btn.setToolButtonStyle(button_style)
     btn.setObjectName(object_name)
     if text:
         btn.setText(text)
@@ -532,66 +541,6 @@ def add_field(layout: QLayout, field: QWidget, label=None, index=-1):
         add_to_layout(layout, w, index)
 
 
-class UnitToken:
-    """
-    字段单元代表符号
-    不要声明为枚举类型，方便json传递时直接使用字面量名称
-    """
-    TEXT = '*'  # 文本
-    SWITCH = '!'  # 开关
-    NUMBER = '.'  # 小数
-    CURRENCY = '$'  # 金额
-    INT = '#'  # 整数
-    DATE = 'd'  # 日期
-    TIME = 't'  # 日期时间
-    YEAR = 'y'  # 年份
-    YEAR_MONTH = 'm'  # 年月
-    CHOOSE = '@'  # 字典或码表选择
-    LOOKUP = '?'  # 对照映射
-    PERCENT = '%'  # 百分比
-    CLOCK = 'cl'  # 时刻
-    RICH_TEXT = 'rt'  # 长文本
-
-
-class UnitType(Enum):
-    TEXT = '*'  # 文本
-    SWITCH = '!'  # 开关
-    NUMBER = '.'  # 小数
-    CURRENCY = '$'  # 金额
-    INT = '#'  # 整数
-    DATE = 'd'  # 日期
-    TIME = 't'  # 日期时间
-    YEAR = 'y'  # 年份
-    YEAR_MONTH = 'm'  # 年月
-    CHOOSE = '@'  # 字典或码表选择
-    LOOKUP = '?'  # 对照映射
-    PERCENT = '%'  # 百分比
-    CLOCK = 'cl'  # 时刻
-    RICH_TEXT = 'rt'  # 长文本
-
-
-class ChooseFlag:
-    """
-    选择单元的具体选取模式
-    不要声明为枚举类型，方便json传递时直接使用字面量名称
-    """
-    LIST = 0
-    RADIO = 1
-    CHECK = 2
-
-
-class AttitudeToken:
-    """
-    显示调性
-    """
-    NEGATIVE = '--'  # 阴性: 消极/反向/负面/异常/出错
-    WEAK_NEGATIVE = '-'  # 弱阴 - 预警
-    NEUTRAL = '='  # 中性
-    WEAK_POSITIVE = '+'  # 弱阳
-    POSITIVE = '++'  # 阳性: 积极/正向/正面/正常/无差错
-    INACTIVE = '~'  # 失能：处于无效/失效状态
-
-
 class WorkMode(Enum):
     """
     单元的工作模式，显示/编辑
@@ -618,15 +567,6 @@ class Stage(Enum):
     IN_QUERY = 2  # 查询条件
 
 
-class ChooseMode(Enum):
-    """
-    选择单元的具体选取模式
-    """
-    LIST = 0
-    RADIO = 1
-    CHECK = 2
-
-
 class TranslateDirection(Enum):
     TO_TEXT = 0  # 值 -> 显示文字
     TO_VALUE = 1  # 显示文字 -> 值
@@ -641,49 +581,6 @@ class LookupViewType(Enum):
     Tree = 2  # 树：有表头，可以多列，树形展开，无查询条件录入框
 
 
-class DisplayAttitude(Enum):
-    """
-    显示调性,可根据
-    """
-    NEGATIVE = '--'  # 阴性: 消极/反向/负面/异常/出错
-    WEAK_NEGATIVE = '-'  # 弱阴 - 预警
-    NEUTRAL = '='  # 中性
-    WEAK_POSITIVE = '+'  # 弱阳
-    POSITIVE = '++'  # 阳性: 积极/正向/正面/正常/无差错
-    INACTIVE = '~'  # 失能：处于无效/失效状态
-
-
-class QueryOp(Enum):
-    EQU = '='
-    GE = '>='  # >=
-    GT = '>'  # >
-    LE = '<='  # <=
-    LT = '<'  # <
-    NEQ = '!='  # !=
-    BETWEEN = '~'
-    IN = '@'
-    NOT_IN = '!@'  # not in
-    LIKE = '*'
-    NOT_LIKE = '!*'  # not like
-    LIKE_IN = '**'  # like A or like B or like C ...
-
-    def text(self):
-        return {
-            self.EQU: '等于',
-            self.GE: '不低于',
-            self.GT: '高于',
-            self.LE: '不高于',
-            self.LT: '小于',
-            self.NEQ: '不等于',
-            self.BETWEEN: '范围',
-            self.IN: '属于',
-            self.NOT_IN: '不属于',
-            self.LIKE: '匹配',
-            self.NOT_LIKE: '不匹配',
-            self.LIKE_IN: '用"|"分隔的多值匹配',
-        }.get(self)
-
-
 def alignment_flag(tag):
     """
     :param tag:
