@@ -14,13 +14,12 @@ from PySide6.QtWidgets import QWidget, QFormLayout, QLineEdit, QLayout, \
     QStyledItemDelegate, QTableView, QSizePolicy, QTextEdit, QGroupBox, QVBoxLayout, QTreeView
 from pandas import Timestamp
 
-from .wdg import YearMonthSpin
-from yus import ColumnSpec
+from yus import ColumnSpec, Op, UnitType, ChooseMode, DisplayAttitude
 from yut import to_float, to_date, to_datetime, is_execute_able, format_date, has_attr, get_attr, \
     set_attr, format_datetime, o2d, is_collection, copy_obj, create_instance
-from . import Stage, WorkMode, ChooseMode, UnitType, DisplayAttitude, QueryOp, add_to_layout, img, \
-    current_theme, alignment_flag
+from . import Stage, WorkMode, add_to_layout, img, current_theme, alignment_flag
 from . import add_field, create_layout_widget, create_layout, clear_layout, set_label_color, load_icon, create_button
+from .wdg import YearMonthSpin
 from .ydict import DictFetcher
 
 
@@ -57,7 +56,7 @@ class YFieldWidget(QTextEdit):
             font.setBold(font_bold)
             self.setFont(font)
         height = get_attr(self.col_spec, 'height', None)
-        if self.col_spec.unit_type() != UnitType.RICH_TEXT:
+        if self.col_spec.utype() != UnitType.RICH_TEXT:
             self.setFixedHeight(self.fontMetrics().height() + 12)
             self.setSizePolicy(QSizePolicy.Policy.Expanding, QSizePolicy.Policy.Minimum)
         else:  # 长文本类型，尽可能大
@@ -70,9 +69,9 @@ class YFieldWidget(QTextEdit):
         alignment = get_attr(spec, 'alignment')
         if alignment:  # 优先使用列规格中的对齐属性
             return alignment_flag(alignment)
-        elif spec.unit_type() in (UnitType.CURRENCY, UnitType.INT, UnitType.NUMBER):
+        elif spec.utype() in (UnitType.CURRENCY, UnitType.INT, UnitType.NUMBER):
             return Qt.AlignmentFlag.AlignRight | Qt.AlignmentFlag.AlignVCenter
-        elif spec.unit_type() in (UnitType.CHOOSE, UnitType.LOOKUP, UnitType.DATE):
+        elif spec.utype() in (UnitType.CHOOSE, UnitType.LOOKUP, UnitType.DATE):
             return Qt.AlignmentFlag.AlignCenter | Qt.AlignmentFlag.AlignVCenter
         return Qt.AlignmentFlag.AlignLeft | Qt.AlignmentFlag.AlignVCenter
 
@@ -93,8 +92,8 @@ class YFieldWidget(QTextEdit):
             add_field(layout, self, label)
 
     def get_field_label(self):
-        # label 依次使用 label/comment/field属性
-        label: str = get_attr(self, 'label', None)
+        # label 依次使用 title/comment/field属性
+        label: str = get_attr(self, 'title', None)
         if label is None:
             label = get_attr(self, 'comment', None)
         if label is None:
@@ -141,8 +140,8 @@ class YDisplayDelegate(QStyledItemDelegate):
         self.view = view
         self.col_spec = col_spec
         self.name = col_spec.name
-        self.label = col_spec.title()
-        self.utype = self.factory.deduce_unit_type(col_spec=self.col_spec)  # UnitType(col_spec.unit_type())
+        self.label = col_spec.title
+        self.utype = self.factory.deduce_unit_type(col_spec=col_spec)  # UnitType(col_spec.unit_type())
         self.comment = col_spec.comment
         self.fv_kwargs = kwargs
         self._field_painter = self.factory.get_painter(self.col_spec, **self.fv_kwargs)
@@ -573,11 +572,11 @@ class YFdChoose(YFieldEditor):
         self.code_dict = DictFetcher.instance().get_dict(self)
         if self.code_dict is None:
             self.code_dict = {}
-        self.query_op = get_attr(self, 'op', QueryOp.IN)
-        self.mode = get_attr(self, 'mode', ChooseMode.LIST.value)
+        self.query_op = get_attr(self, 'op', Op.IN)
+        self.mode = get_attr(self, 'mode', ChooseMode.LIST)
         self.format = get_attr(self, 'format', '[{code}] - {name}')
         # 如果是查询场景，mode自动设置为checkbox,布局根据可选项数量确定为'V'或'G2'
-        if self.stage == Stage.IN_QUERY and self.query_op != QueryOp.EQU:
+        if self.stage == Stage.IN_QUERY and self.query_op != Op.EQU:
             self.mode = ChooseMode.CHECK
             self.layout_flag = get_attr(self, 'layout_flag', 'V') if len(self.code_dict.keys()) < 6 else 'G2'
         else:
@@ -974,7 +973,7 @@ class YFpChoose(YFieldPainter):
             return None
         for att, v in self.attitude.items():
             if value in v:
-                return self.get_attitude_color(DisplayAttitude(att))
+                return self.get_attitude_color(att)
         return None
 
     def setup_painter(self, painter, value, text):
@@ -1016,7 +1015,7 @@ class YFdCriteria(QWidget):
                  column_spec,
                  parent=None,
                  editor_cls=None,
-                 op: QueryOp = None,
+                 op: Op = None,
                  value=None,
                  layout_flag='H',
                  check_able=True,
@@ -1026,10 +1025,10 @@ class YFdCriteria(QWidget):
         self.column_spec = column_spec
         self.editor_cls = editor_cls if editor_cls else FACTORY.get_editor_class(self.column_spec)
         self.field = column_spec.name
-        self.label = self.column_spec.title()
-        self.check_able = check_able
+        self.label = self.column_spec.title if self.column_spec.title else self.column_spec.comment
         if self.label is None:
             self.label = self.field.upper()
+        self.check_able = check_able
         if self.label.startswith('*'):
             self.label = self.label[1:]
         self.layout_flag = layout_flag
@@ -1045,16 +1044,16 @@ class YFdCriteria(QWidget):
 
     def get_default_op(self):
         return {
-            YFdText: QueryOp.LIKE_IN,
-            YFdNumber: QueryOp.BETWEEN,
-            YFdInt: QueryOp.BETWEEN,
-            YFdYear: QueryOp.BETWEEN,
-            YFdCurrency: QueryOp.BETWEEN,
-            YFdDate: QueryOp.BETWEEN,
-            YFdDateTime: QueryOp.BETWEEN,
-            YFdYearMonth: QueryOp.BETWEEN,
-            YFdChoose: QueryOp.IN,
-            YFdLookup: QueryOp.IN,
+            YFdText: Op.LIKE_IN,
+            YFdNumber: Op.BETWEEN,
+            YFdInt: Op.BETWEEN,
+            YFdYear: Op.BETWEEN,
+            YFdCurrency: Op.BETWEEN,
+            YFdDate: Op.BETWEEN,
+            YFdDateTime: Op.BETWEEN,
+            YFdYearMonth: Op.BETWEEN,
+            YFdChoose: Op.IN,
+            YFdLookup: Op.IN,
         }[self.editor_cls]
 
     def add_to(self, layout: QLayout, index=-1):
@@ -1127,7 +1126,7 @@ class YFdCriteria(QWidget):
                 return
             if not is_collection(o_value):
                 raise Exception('查询条件值不符合要求，应为集合类型，且对应两个元素： (Op,Value)')
-            new_op = QueryOp(o_value[0])
+            new_op = Op(o_value[0])
             if new_op != self.op:  # 重置界面
                 self.op = new_op
                 self.setup_ui()
@@ -1141,7 +1140,7 @@ class YFdCriteria(QWidget):
         self._checked = sender.isChecked()
 
     def is_editor_pair(self):
-        return self.op == QueryOp.BETWEEN
+        return self.op == Op.BETWEEN
 
     def set_value(self, value):
         values = value if self.is_editor_pair() else [value]
@@ -1195,7 +1194,6 @@ class YFdFactory:
         # 简单使用col_spec确定的utype
         utype = get_attr(col_spec, 'utype')
         if utype:  # 指定了明确的utype，直接返回
-            utype = UnitType(utype)
             set_attr(col_spec, 'utype', utype)
             return utype
         # 没有明确指定utype,根据类型推断
