@@ -9,9 +9,9 @@ import pandas as pd
 from PySide6.QtCore import QAbstractTableModel, QModelIndex, Qt, QAbstractItemModel, QSize
 from pandas import DataFrame
 
-from . import TranslateDirection, filename_for_save, QueryOp, alignment_flag
+from . import TranslateDirection, filename_for_save, alignment_flag
 from .yfield import FACTORY
-from yus import ColumnSpec, to_column_spec
+from yus import ColumnSpec, Op
 from yut import is_collection, format_obj, get_attr, set_attr, is_execute_able
 
 
@@ -33,7 +33,7 @@ class PandasModel(QAbstractTableModel):
         """
         super().__init__()
         self._data = data
-        self._spec = {get_attr(o, 'name'): to_column_spec(o) for o in spec} if spec else {}
+        self._spec = {get_attr(o, 'name'): ColumnSpec.from_obj(o) for o in spec} if spec else {}
         self._display_columns = display_columns if display_columns is not None else self._data.columns.tolist()
         self.for_edit = for_edit
         self._custom_style_handler = custom_style_handler
@@ -158,7 +158,7 @@ class PandasModel(QAbstractTableModel):
         if role == Qt.ItemDataRole.DisplayRole:
             if orientation == Qt.Orientation.Horizontal:  # 列标题
                 col_name = self._display_columns[section]
-                return self.column_spec(col_name).title()
+                return self.column_spec(col_name).title
             else:  # 行标题
                 # row_dat = self.data_of_row(section)
                 # col = self._display_columns[0]
@@ -309,7 +309,7 @@ class YTreeModel(QAbstractItemModel):
                  parent=None):
         super().__init__(parent)
         self._data = data
-        self._spec = {get_attr(o, 'name'): to_column_spec(o) for o in spec}
+        self._spec = {get_attr(o, 'name'): ColumnSpec.from_obj(o) for o in spec}
         self._field_painters = {name: FACTORY.get_painter(spec) for name, spec in self._spec.items()}
         self.id_extractor = id_extractor
         self.parent_id_extractor = parent_id_extractor
@@ -426,7 +426,7 @@ class YTreeModel(QAbstractItemModel):
     def headerData(self, section: int, orientation: Qt.Orientation, role=Qt.ItemDataRole.DisplayRole) -> Any:
         if role == Qt.ItemDataRole.DisplayRole and orientation == Qt.Orientation.Horizontal:
             col = self.columns[section] if section < len(self.columns) else None
-            return self.column_spec(col).title() if col else None
+            return self.column_spec(col).title if col else None
         return None
 
     def _get_item(self, index: QModelIndex) -> YTreeItem:
@@ -439,7 +439,7 @@ class YTreeModel(QAbstractItemModel):
         return self._data
 
 
-def add_qc_value(o, attr, op: QueryOp, value):
+def add_qc_value(o, attr, op: Op, value):
     v = (op.value, value)
     if isinstance(o, dict):
         o[attr] = v
