@@ -16,11 +16,13 @@ from PySide6.QtWidgets import (
 from matplotlib.backends.backend_qt5agg import FigureCanvasQTAgg as FigureCanvas
 from matplotlib.backends.backend_qt5agg import NavigationToolbar2QT as NavigationToolbar
 from matplotlib.figure import Figure
+from pandas import DataFrame
 
 import yui
-from yui import UnitType, img, current_theme, create_layout, create_button, load_icon
+from yui import img, current_theme, create_layout, create_button, load_icon
 from yui.wdg import YTitle, YWidgetPages, YLink, YSortableTable, YSortableItem
 from yui.ymodel import PandasModel
+from yus import UnitType
 
 # 设置Matplotlib支持中文
 plt.rcParams['font.sans-serif'] = ['SimHei']  # 用来正常显示中文标签
@@ -100,7 +102,6 @@ class YStatsChart(QWidget):
         self.canvas.axes.set_title('')
         self.canvas.axes.grid(False)
         self.canvas.axes.set_axis_on()  # 确保坐标轴显示
-        # 修复坐标轴比例问题
         self.canvas.axes.set_aspect('auto')  # 重置为自动比例
         self.canvas.axes.relim()  # 重新计算坐标轴范围
         self.canvas.axes.autoscale_view()  # 自动调整视图范围
@@ -147,14 +148,14 @@ class YStatsChart(QWidget):
             ax.axis('equal')
             ax.set_title(f'{group_field_cn} - {field_cn} {stats_func}')
 
-        elif chart_type in [ChartType.BAR, ChartType.LINE]:
+        elif chart_type in [ChartType.BAR, ChartType.LINE]:  # 柱图和折线图
             x = np.arange(len(labels))
 
             # 清除之前的图例
             if ax.legend_:
                 ax.legend_.remove()
 
-            # 单数值列（计数）
+            # 单数值列
             if isinstance(values, list):
                 if chart_type == ChartType.BAR:
                     # 创建柱状图
@@ -319,7 +320,7 @@ class StatsCalculator:
     ColSumText = '<总计>'
 
     @staticmethod
-    def group_stats(df, group_field, stats_type, value_fields, value_columns=None, units=1):
+    def group_stats(df: DataFrame, group_field: str, stats_type: StatsType, value_fields, value_columns=None, units=1):
         """
         执行分组统计
         参数:
@@ -328,6 +329,7 @@ class StatsCalculator:
             stats_type: 统计方式 (StatsType枚举)
             value_fields: 数值列列表
             value_columns: 数值列列表（可选）
+            units: 金额单位（元、万元）
         返回:
             分组统计结果DataFrame（包含合计行）
         """
@@ -381,7 +383,7 @@ class StatsCalculator:
         return pd.concat([result_df, total_row.to_frame().T], ignore_index=True)
 
     @staticmethod
-    def cross_stats(df, row_field, col_field, value_field, stats_type, units=1):
+    def cross_stats(df: DataFrame, row_field: str, col_field: str, value_field: str, stats_type: StatsType, units=1):
         """
         执行交叉统计
         参数:
@@ -422,9 +424,10 @@ class StatsCalculator:
 class GroupStatsWidget(QWidget):
     filteredData = Signal(object, str)  # 过滤后的数据mask,说明文字
 
-    def __init__(self, parent=None):
+    def __init__(self, parent=None, count_only=False):
         super().__init__(parent)
         self.df = None
+        self.count_only = count_only
         self.cn_mapping = {}
         self.value_columns = []  # 外部传入的数值列
         self.chart_fullscreen = False
@@ -445,25 +448,27 @@ class GroupStatsWidget(QWidget):
         fbox.setVerticalSpacing(6)
         fbox.setHorizontalSpacing(20)
 
-        # 数值列选择
+        # 数值列
         self.value_list = QListWidget()
         self.value_list.setMaximumHeight(100)
         fbox.addRow(YTitle.create_label('数值列：'), self.value_list)
         self.units_10k = QCheckBox('启用（万元）转换')
+        self.units_10k.setEnabled(not self.count_only)
         fbox.addRow(QLabel(''), self.units_10k)
 
-        # 分组字段选择
-        self.group_combo = QComboBox()
-        fbox.addRow(YTitle.create_label('分组字段：'), self.group_combo)
-
         # 统计方式
         self.stats_combo = QComboBox()
         # 使用枚举值填充下拉框
         for stat in StatsType:
-            self.stats_combo.addItem(load_icon(img.P_BULLET3),stat.value, stat)
-        self.stats_combo.setCurrentText(StatsType.SUM.value)
+            self.stats_combo.addItem(load_icon(img.P_BULLET3), stat.value, stat)
+        self.stats_combo.setCurrentText(StatsType.COUNT.value if self.count_only else StatsType.SUM.value)
+        self.stats_combo.setEnabled(not self.count_only)
         fbox.addRow(YTitle.create_label('统计方式：'), self.stats_combo)
 
+        # 分组字段
+        self.group_combo = QComboBox()
+        fbox.addRow(YTitle.create_label('分组字段：'), self.group_combo)
+
         # 统计按钮
         self.stats_btn = create_button("执行统计", self.perform_stats, icon_file=img.P_LIGHTNING, flat=False)
         self.stats_btn.setFixedSize(QSize(200, 30))
@@ -474,7 +479,7 @@ class GroupStatsWidget(QWidget):
         self.result_table.cellClicked.connect(self.handle_cell_click)
 
         left_box.addLayout(fbox, stretch=0)
-        left_box.addWidget(self.stats_btn,alignment=Qt.AlignmentFlag.AlignCenter)
+        left_box.addWidget(self.stats_btn, alignment=Qt.AlignmentFlag.AlignCenter)
         left_box.layout().addWidget(self.result_table, stretch=1)
 
         # 右侧图表及全屏按钮
@@ -552,7 +557,10 @@ class GroupStatsWidget(QWidget):
             item = QListWidgetItem(cn_name)
             item.setData(Qt.ItemDataRole.UserRole, col)
             item.setFlags(item.flags() | Qt.ItemFlag.ItemIsUserCheckable)
-            item.setCheckState(Qt.CheckState.Unchecked if i > 0 else Qt.CheckState.Checked)  # 默认选中第一个
+            if not self.count_only and i == 0:
+                item.setCheckState(Qt.CheckState.Checked)  # 选中第一个
+            else:
+                item.setCheckState(Qt.CheckState.Unchecked)  # 不可省略，否则不显示复选框
             item.setIcon(yui.load_icon(img.P_LABEL))
             self.value_list.addItem(item)
         # 初始化数值列状态
@@ -739,9 +747,10 @@ class GroupStatsWidget(QWidget):
 class CrossStatsWidget(QWidget):
     filteredData = Signal(object, str)  # 过滤后的数据mask,说明文字
 
-    def __init__(self, parent=None):
+    def __init__(self, parent=None, count_only=False):
         super().__init__(parent)
         self.df = None  # 执行统计时使用的df,通常是预处理之后的
+        self.count_only = count_only
         self.cn_mapping = {}
         self.value_columns = []  # 外部传入的数值列
         self.chart_fullscreen = False
@@ -768,6 +777,8 @@ class CrossStatsWidget(QWidget):
         self.value_combo = QComboBox()
         hbox.addWidget(YTitle.create_label('数值列：', buddy=self.value_combo))
         self.units_10k = QCheckBox('启用（万元）转换')
+        self.units_10k.setEnabled(not self.count_only)
+        self.value_combo.setEnabled(not self.count_only)
         hbox.addWidget(self.units_10k)
         hbox.addSpacing(40)
 
@@ -775,9 +786,10 @@ class CrossStatsWidget(QWidget):
         self.stats_combo = QComboBox()
         # 使用枚举值填充下拉框
         for stat in StatsType:
-            self.stats_combo.addItem(load_icon(img.P_BULLET3),stat.value, stat)
-        self.stats_combo.setCurrentText(StatsType.SUM.value)
+            self.stats_combo.addItem(load_icon(img.P_BULLET3), stat.value, stat)
+        self.stats_combo.setCurrentText(StatsType.COUNT.value if self.count_only else StatsType.SUM.value)
         hbox.addWidget(YTitle.create_label('统计方式：', buddy=self.stats_combo))
+        self.stats_combo.setEnabled(not self.count_only)
         hbox.addSpacing(40)
 
         # 行列字段
@@ -1080,7 +1092,7 @@ class YStatWidget(QWidget):
 
     filterModel = Signal(PandasModel, str)  # 过滤后的model，描述文字，通常是过滤条件说明
 
-    def __init__(self, parent=None):
+    def __init__(self, parent=None, count_only=False):
         super().__init__(parent)
 
         YStatWidget.LINK_COLOR = self.palette().link()
@@ -1089,8 +1101,9 @@ class YStatWidget(QWidget):
 
         self.model = None
         self.df = None
-        self.group_tab = GroupStatsWidget()
-        self.cross_tab = CrossStatsWidget()
+        self.count_only = count_only
+        self.group_tab = GroupStatsWidget(count_only=self.count_only)
+        self.cross_tab = CrossStatsWidget(count_only=self.count_only)
         self.pages = YWidgetPages(YLink('分组统计', icon=img.P_SUM_1, target=self.group_tab),
                                   YLink('交叉统计', icon=img.P_TREE, target=self.cross_tab),
                                   parent=self,
@@ -1124,8 +1137,7 @@ class YStatWidget(QWidget):
         # 处理Choose列，使用显示文字替换原始值
         df = self.model.data_frame().copy()
         column_specs = self.model.column_specs()
-        choose_columns = [spec.name for spec in column_specs if
-                          spec.unit_type() in (UnitType.CHOOSE, UnitType.LOOKUP)]
+        choose_columns = [spec.name for spec in column_specs if spec.utype in (UnitType.CHOOSE, UnitType.LOOKUP)]
         for col in choose_columns:
             try:
                 col_idx = self.model._display_columns.index(col)
@@ -1142,7 +1154,7 @@ class YStatWidget(QWidget):
         column_specs = self.model.column_specs()
         col_map = {sp.name: sp.comment for sp in column_specs}
         if not value_columns:
-            value_columns = [sp.name for sp in column_specs if sp.unit_type() in (UnitType.CURRENCY, UnitType.INT)]
+            value_columns = [sp.name for sp in column_specs if sp.utype in (UnitType.CURRENCY, UnitType.INT)]
         self.set_data_frame(df, column_names=col_map, value_columns=value_columns)
 
 
@@ -1211,7 +1223,7 @@ class MainWindow(QMainWindow):
         value_columns = ['income', 'expense', 'bonus']
 
         # 创建主部件
-        self.stats_widget = YStatWidget()
+        self.stats_widget = YStatWidget(count_only=False)
         self.stats_widget.set_data_frame(self.df, CN_MAPPING, value_columns)
         self.stats_widget.filterModel.connect(lambda model, txt: print(txt, model.data_frame().to_string()))
 
