@@ -103,7 +103,7 @@ class YTableView(QTableView):
                 self.setItemDelegateForColumn(col_index, delegate)
             style = cell_styles.get(col)
             if style is None:  # 按照默认
-                self.setColumnWidth(col_index, model.column_spec(col).perfect_column_width())
+                self.setColumnWidth(col_index, 100)
             else:
                 self.setColumnWidth(col_index, style.width())
             col_index = col_index + 1
@@ -237,7 +237,9 @@ class YTableWidget(QWidget):
                  left_bar_visible=True,
                  right_bar_visible=True,
                  status_bar_visible=True,
-                 title_alignment=Qt.AlignmentFlag.AlignLeft, ):
+                 title_alignment=Qt.AlignmentFlag.AlignLeft,
+                 stat_count_only=False,
+                 ):
         """
 
         :param title:
@@ -270,6 +272,7 @@ class YTableWidget(QWidget):
         self.hidden_columns = hidden_columns
         self.merged_columns = merged_columns
         self.title_alignment = title_alignment
+        self.stat_count_only = stat_count_only
         self.model = model
         if model is None:
             self.set_model(self.query_model())
@@ -394,13 +397,15 @@ class YTableWidget(QWidget):
             create_tool_button('刷新',
                                trigger=self.load_data,
                                flat=True,
-                               # icon_only=True,
-                               icon_file=img.P_REFRESH),
+                               parent=self,
+                               icon_file=img.P_REFRESH,
+                               object_name='btn_refresh', ),
             create_tool_button('统计',
                                trigger=self.stat_model,
+                               parent=self,
                                flat=True,
-                               # icon_only=True,
-                               icon_file=img.P_CHART_LINEBAR),
+                               icon_file=img.P_CHART_LINEBAR,
+                               object_name='btn_stat'),
             create_menu_button(more_menu,
                                title='更多...',
                                icon_file=img.P_3DOTS_V,
@@ -505,7 +510,7 @@ class YTableWidget(QWidget):
 
     def stat_model(self):
         def create_stat_widget():
-            stats_widget = YStatWidget()
+            stats_widget = YStatWidget(count_only=self.stat_count_only)
             if self.title:
                 stats_widget.setWindowTitle(f"{self.title}-统计")
             else:
@@ -561,7 +566,7 @@ class YTableWidget(QWidget):
         if not hasattr(status_bar, '_sum'):
             status_bar._sum = dict()
             for col_name, value in sum_dict.items():
-                label = self.model.column_spec(col_name).title()
+                label = self.model.column_spec(col_name).title
                 span = create_layout(layout_flag='H')
                 span.setContentsMargins(2, 2, 2, 2)
                 lb = create_button(text=f"{label}合计:", icon=load_icon(img.P_SUM), flat=True)
@@ -578,6 +583,11 @@ class YTableWidget(QWidget):
             for col_name, value in sum_dict.items():
                 status_bar._sum[col_name].setText(f"{value:,.2f}")
 
+    def set_buttons_styles(self):
+        btn_style = Qt.ToolButtonStyle.ToolButtonIconOnly if self.width() < 600 else Qt.ToolButtonStyle.ToolButtonTextBesideIcon
+        for obj_name in ('btn_refresh', 'btn_stat'):
+            self.findChild(QToolButton, obj_name).setToolButtonStyle(btn_style)
+
     def refresh_status(self):
         if self.model is None:
             return
@@ -586,6 +596,7 @@ class YTableWidget(QWidget):
             self.status_sum({sc: self.model.summary(sc) for sc in self.summary})
         else:
             self._status_bar.layout().addStretch(0)  # 占位，否则无合计时消息栏位置靠右
+        self.set_buttons_styles()
 
     def toolbar_left(self):
         return self.findChild(QToolBar, 'toolbar_left')
