@@ -13,7 +13,7 @@ from sqlalchemy.sql.elements import quoted_name
 from sqlalchemy.types import TypeDecorator
 
 from yut import CaseInsensitiveDict, Obj, is_collection, o2d, is_execute_able, get_attr, set_attr, call_exp
-from . import Op, get_database_uri, QueryR
+from . import Op, QueryR
 
 
 def extract_qc(params: dict | object | Obj, name: str) -> None | Obj:
@@ -257,6 +257,7 @@ class Selection:
 
         ret = [{'key': c.key,
                 'name': c.name,
+                'title': col_comment(c),# 反射出的字段描述通常放在comment中，赋值给title属性
                 'comment': col_comment(c),
                 'dtype': f"{c.type}" if c.type is not None else None,
                 'table': f"{c.table}" if c.table is not None else None,
@@ -484,12 +485,13 @@ class Selection:
 
 class MetaDb:
     DEFAULT_MODEL_TPL = 'db_models.ptl'
+    DEFAULT_DATABASE_URI = 'sqlite:///:memory:'
 
     def __init__(self, database_url=None, echo=False):
         if database_url:
             self.database_url = database_url
         else:
-            self.database_url = get_database_uri()
+            self.database_url = MetaDb.DEFAULT_DATABASE_URI
         self.engine = create_engine(self.database_url, echo=echo)
         self.meta = MetaData()
         self.meta.reflect(bind=self.engine, views=True)
@@ -626,7 +628,7 @@ class MetaDb:
                    'create_time': datetime.now(),
                    }
         context.update(kwargs)
-        env = jinja2.Environment(loader=jinja2.FileSystemLoader("templates"))
+        env = jinja2.Environment(loader=jinja2.FileSystemLoader("../../templates"))
         rendered_code = env.get_template(tpl_file).render(**context)
         # 保存到文件
         if save_to_file:
